<?php
/* Copyright (C) 2011 by Texas Instruments Incorporated.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Robert Jenks (rjenks@ti.com)
 */
class filter_tinspireurlconverter extends moodle_text_filter {

	/* Generates the replacement text from the URL we found. */
	private static function callback($match) {
		$url = $match[1];
		$query = $match[2];
		$label = $match[3];

		// Defaults 
		$width = 700;
		$height = 500;
		$scrolling = 'no';
		$frameborder = 0;
		$lock_toolbar = 'no';
		$openDoc = 'yes';

		// do we have query options?
		if (isset($query)) {
			$query = htmlspecialchars_decode($query);

			// parse the URL query string into an associative array
			parse_str($query, $output);
			
			// First, check to see if they don't want to convert the link to the player
			if (array_key_exists('x', $output)) {
				// then we just return the original link
				return $match[0];
			}
			
			//if valid, the width parameter
			if (isset($output['width'])) {
				$w = intval($output['width']);
				// reasonable min and max
				if ($w >= 320 && $w <= 2000) {
					$width = $w;
				}
			}
			
			// if valid, use the height parameter
			if (isset($output['height'])) {
				$h = intval($output['height']);
				// reasonable min and max
				if ($h >= 240 && $h <= 2000) {
					$height = $h;
				}
			}
			
			// if valid, use the scrolling parameter
			if ($output['scrolling'] == 'yes') {
				$scrolling = 'yes';
			}
			
			// if valid, use the frameborder parameter
			if ($output['frameborder'] == '1') {
				$frameborder = 1;
			}

			// if valid, use the lock_toolbar parameter
			if ($output['lock_toolbar'] == 'yes') {
				$lock_toolbar = 'yes';
			}

			// if valid, use the openDoc parameter
			if ($output['openDoc'] == 'no') {
				$openDoc = 'no';
			}
		}
		return "<iframe src=\"http://education.ti.com/go/nspireplayer?lock_toolbar=${lock_toolbar}&openDoc=${openDoc}&nspirefile=${url}\" width=\"${width}\" height=\"${height}\" scrolling=\"${scrolling}\" frameborder=\"${frameborder}\"></iframe><br><a href=\"${url}\">${label}</a><br>";
	}

    public function filter($text, array $options = array()) {
		$pattern = "/<a\s[^>]*?href=\"([^<]+\.tnsp?)(?:\?([^\"]*))?\"[^>]*?>(.*?)<\/a>/is";
        return preg_replace_callback($pattern, 'filter_tinspireurlconverter::callback', $text);
    }

}
?>